Enum InsertTarget
pub enum InsertTarget {
Scope(Box<Query>),
Model(ModelId),
Table(InsertTable),
}Variants
Scope(Box<Query>)
Inserting into a scope implies that the inserted value should be included by the query after insertion. This could be a combination of setting default field values or validating existing ones.
Model(ModelId)
Insert a model
Table(InsertTable)
Insert into a table
Implementations
impl InsertTarget
impl InsertTarget
pub fn is_model(&self) -> bool
pub fn as_model_unwrap(&self) -> ModelId
pub fn is_table(&self) -> bool
pub fn as_table_unwrap(&self) -> &InsertTable
pub fn add_constraint(&mut self, expr: impl Into<Expr>)