TableRef

Enum TableRef 

pub enum TableRef {
    Cte {
        nesting: usize,
        index: usize,
    },
    Derived(TableDerived),
    Table(TableId),
    Arg(ExprArg),
}

Variants



Cte

An aliased table (in a FROM statement or equivalent).

Fields

nesting: usize

What level of nesting the reference is compared to the CTE being referenced.

index: usize

The index of the CTE in the WITH clause



Derived(TableDerived)

A table derived from a query



Table(TableId)

A defined table from the schema



Arg(ExprArg)

The table ref will be provided at a later time (and will become a derived table)

Implementations



impl TableRef

pub fn references(&self, table_id: TableId) -> bool

pub fn is_cte(&self) -> bool