Enum UpsertTarget
pub enum UpsertTarget {
Fields(Vec<Projection>),
Columns(Vec<ColumnId>),
}Expand description
The fields or columns that identify the selected upsert conflict.
Variants
Fields(Vec<Projection>)
Model-field projections used before engine lowering.
Columns(Vec<ColumnId>)
Database columns sent to the driver after engine lowering.