pub struct AddColumn {
pub table: TableId,
pub column: ColumnDef,
}Expand description
A statement to add a column to a table.
Fields
table: TableIdID of the table to add the column to.
column: ColumnDefColumn definition.