Struct Association
pub struct Association {
pub source: Box<Query>,
pub path: Path,
}Expand description
A reference to an association traversal from a source query.
Used in SourceModel::via to indicate that a model
is reached by following a relation path from another query’s results.
Examples
ⓘ
use toasty_core::stmt::{Association, Query, Path};
let assoc = Association {
source: Box::new(Query::unit()),
path: Path::from(vec![0]),
};Fields
source: Box<Query>The source query whose results are the starting point.
path: PathThe field path from the source model to the target model.