Struct Delete
pub struct Delete {
pub from: Source,
pub filter: Filter,
pub returning: Option<Returning>,
}Expand description
A DELETE statement that removes existing records.
Specifies a source to delete from, a filter selecting which records to delete, and an optional returning clause.
Examples
ⓘ
use toasty_core::stmt::{Delete, Source, Filter};
use toasty_core::schema::app::ModelId;
let delete = Delete {
from: Source::from(ModelId(0)),
filter: Filter::default(),
returning: None,
};Fields
from: SourceThe source to delete from (FROM clause).
filter: FilterFilter selecting which records to delete (WHERE clause).
returning: Option<Returning>Optional RETURNING clause.
Implementations