pub struct DropColumn {
pub table: TableId,
pub name: Name,
pub if_exists: bool,
}Expand description
A statement to drop a column from a table.
Fields
table: TableIdID of the table to drop the column from.
name: NameName of the column to drop.
if_exists: boolWhether or not to add an IF EXISTS clause.