Struct ExprInList
pub struct ExprInList {
pub expr: Box<Expr>,
pub list: Box<Expr>,
}Expand description
Tests whether a value is contained in a list.
Returns true if expr equals any item in list. Returns false for an
empty list.
Examples
in_list(x, [1, 2, 3]) // returns `true` if x is 1, 2, or 3
in_list(x, []) // returns `false`Fields
expr: Box<Expr>The value to search for.
list: Box<Expr>The list to search within.