pub trait Project {
// Required method
fn project(self, projection: &Projection) -> Option<Expr>;
}Expand description
Trait for types that can be projected through a Projection.
Returns the projected expression, or None if the projection is not
applicable.
Required Methods
Sourcefn project(self, projection: &Projection) -> Option<Expr>
fn project(self, projection: &Projection) -> Option<Expr>
Applies the projection and returns the resulting expression.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".