Function visit_expr_default_mut
pub fn visit_expr_default_mut<V>(v: &mut V)Expand description
Default mutable traversal for Expr::Default nodes. This is a leaf node with no children to visit.
pub fn visit_expr_default_mut<V>(v: &mut V)Default mutable traversal for Expr::Default nodes. This is a leaf node with no children to visit.