Statement

Enum Statement 

pub enum Statement {
Show 14 variants AddColumn(AddColumn), AlterColumn(AlterColumn), AlterTable(AlterTable), CopyTable(CopyTable), CreateIndex(CreateIndex), CreateTable(CreateTable), DropColumn(DropColumn), DropTable(DropTable), DropIndex(DropIndex), Pragma(Pragma), Delete(Delete), Insert(Insert), Query(Query), Update(Update),
}

Variants



AddColumn(AddColumn)



AlterColumn(AlterColumn)



AlterTable(AlterTable)



CopyTable(CopyTable)



CreateIndex(CreateIndex)



CreateTable(CreateTable)



DropColumn(DropColumn)



DropTable(DropTable)



DropIndex(DropIndex)



Pragma(Pragma)



Delete(Delete)



Insert(Insert)



Query(Query)



Update(Update)

Implementations

Source

impl Statement

pub fn add_column(column: &Column, capability: &Capability) -> Self

Adds a column to a table.

Source

impl Statement

pub fn alter_column( column: &Column, changes: AlterColumnChanges, capability: &Capability, ) -> Self

Alters a column.

Source

impl Statement

pub fn alter_table_rename_to(table: &Table, new_name: &str) -> Self

Renames a table.

Source

impl Statement

pub fn copy_table( source: Name, target: Name, columns: Vec<(Name, Name)>, ) -> Self

Creates a statement that copies rows from one table to another.

Source

impl Statement

pub fn create_index(index: &Index) -> Self

Source

impl Statement

pub fn create_table(table: &Table, capability: &Capability) -> Self

Source

impl Statement

pub fn drop_column(column: &Column) -> Self

Drops a column from a table.

This function does not add an IF EXISTS clause.

pub fn drop_column_if_exists(column: &Column) -> Self

Drops a column from a table if it exists.

This function does add an IF EXISTS clause.

Source

impl Statement

pub fn drop_index(index: &Index) -> Self

Drops an index.

This function does not add an IF EXISTS clause.

pub fn drop_index_if_exists(index: &Index) -> Self

Drops a index if it exists.

This function does add an IF EXISTS clause.

Source

impl Statement

pub fn drop_table(table: &Table) -> Self

Drops a table.

This function does not add an IF EXISTS clause.

pub fn drop_table_if_exists(table: &Table) -> Self

Drops a table if it exists.

This function does add an IF EXISTS clause.

Source

impl Statement

pub fn pragma_enable_foreign_keys() -> Self

Sets PRAGMA foreign_keys = ON.

pub fn pragma_disable_foreign_keys() -> Self

Sets PRAGMA foreign_keys = OFF.

pub fn pragma(name: impl Into<String>, value: impl Into<String>) -> Self

Creates a PRAGMA statement with the given name and value.

Source

impl Statement

pub fn is_update(&self) -> bool

pub fn returning_len(&self) -> Option<usize>

Returns the number of returned elements within the statement (if one exists).