Value

Enum Value 

pub enum Value {
Show 23 variants Bool(bool), I8(i8), I16(i16), I32(i32), I64(i64), U8(u8), U16(u16), U32(u32), U64(u64), SparseRecord(SparseRecord), Null, Record(ValueRecord), List(Vec<Value>), String(String), Bytes(Vec<u8>), Uuid(Uuid), Decimal(Decimal), BigDecimal(BigDecimal), Timestamp(Timestamp), Zoned(Zoned), Date(Date), Time(Time), DateTime(DateTime),
}

Variants



Bool(bool)

Boolean value



I8(i8)

Signed 8-bit integer



I16(i16)

Signed 16-bit integer



I32(i32)

Signed 32-bit integer



I64(i64)

Signed 64-bit integer



U8(u8)

Unsigned 8-bit integer



U16(u16)

Unsigned 16-bit integer



U32(u32)

Unsigned 32-bit integer



U64(u64)

Unsigned 64-bit integer



SparseRecord(SparseRecord)

A typed record



Null

Null value



Record(ValueRecord)

Record value, either borrowed or owned



List(Vec<Value>)

A list of values of the same type



String(String)

String value, either borrowed or owned



Bytes(Vec<u8>)

An array of bytes that is more efficient than List(u8)



Uuid(Uuid)

128-bit universally unique identifier (UUID)



Decimal(Decimal)

A fixed-precision decimal number. See [rust_decimal::Decimal].



BigDecimal(BigDecimal)

An arbitrary-precision decimal number. See [bigdecimal::BigDecimal].



Timestamp(Timestamp)

An instant in time represented as the number of nanoseconds since the Unix epoch. See [jiff::Timestamp].



Zoned(Zoned)

A time zone aware instant in time. See [jiff::Zoned]



Date(Date)

A representation of a civil date in the Gregorian calendar. See [jiff::civil::Date].



Time(Time)

A representation of civil “wall clock” time. See [jiff::civil::Time].



DateTime(DateTime)

A representation of a civil datetime in the Gregorian calendar. See [jiff::civil::DateTime].

Implementations



impl Value

pub fn to_i8(&self) -> Option<i8>

pub fn to_i8_unwrap(&self) -> i8

pub fn to_i16(&self) -> Option<i16>

pub fn to_i16_unwrap(&self) -> i16

pub fn to_i32(&self) -> Option<i32>

pub fn to_i32_unwrap(&self) -> i32

pub fn to_i64(&self) -> Option<i64>

pub fn to_i64_unwrap(&self) -> i64

pub fn to_u8(&self) -> Option<u8>

pub fn to_u8_unwrap(&self) -> u8

pub fn to_u16(&self) -> Option<u16>

pub fn to_u16_unwrap(&self) -> u16

pub fn to_u32(&self) -> Option<u32>

pub fn to_u32_unwrap(&self) -> u32

pub fn to_u64(&self) -> Option<u64>

pub fn to_u64_unwrap(&self) -> u64



impl Value



impl Value

pub const fn null() -> Value

Returns a ValueCow representing null

pub const fn is_null(&self) -> bool

pub const fn is_record(&self) -> bool

pub fn record_from_vec(fields: Vec<Value>) -> Value

pub const fn from_bool(src: bool) -> Value

Create a ValueCow representing the given boolean value

pub fn as_str(&self) -> Option<&str>

pub fn expect_string(&self) -> &str

pub fn as_record(&self) -> Option<&ValueRecord>

pub fn expect_record(&self) -> &ValueRecord

pub fn expect_record_mut(&mut self) -> &mut ValueRecord

pub fn into_record(self) -> ValueRecord

pub fn is_a(&self, ty: &Type) -> bool

pub fn infer_ty(&self) -> Type

Infer the type of a value

pub fn entry(&self, path: impl EntryPath) -> Entry<'_>

pub fn take(&mut self) -> Value



impl Value

pub fn list_from_vec(items: Vec<Value>) -> Value

pub fn is_list(&self) -> bool

pub fn unwrap_list(self) -> Vec<Value>