ExprContext

Struct ExprContext 

pub struct ExprContext<'a, T = Schema> { /* private fields */ }

Implementations



impl<'a, T> ExprContext<'a, T>

pub fn schema(&self) -> &'a T

pub fn target(&self) -> ExprTarget<'a>

pub fn target_at(&self, nesting: usize) -> &ExprTarget<'a>

Return the target at a specific nesting



impl<'a> ExprContext<'a, ()>

pub fn new_free() -> ExprContext<'a, ()>



impl<'a, T> ExprContext<'a, T>
where T: Resolve,

pub fn new(schema: &'a T) -> ExprContext<'a, T>

pub fn new_with_target( schema: &'a T, target: impl IntoExprTarget<'a, T>, ) -> ExprContext<'a, T>

pub fn scope<'child>( &'child self, target: impl IntoExprTarget<'child, T>, ) -> ExprContext<'child, T>

pub fn resolve_expr_reference( &self, expr_reference: &ExprReference, ) -> ResolvedRef<'a>

Resolves an ExprReference::Column reference to the actual database Column it represents.

Given an ExprReference::Column (which contains table/column indices and nesting info), returns the Column struct containing the column’s name, type, constraints, and other metadata.

Handles:

  • Nested query scopes (walking up parent contexts based on nesting level)
  • Different statement targets (INSERT, UPDATE, SELECT with joins, etc.)
  • Table references in multi-table operations (using the table index)

Used by SQL serialization to get column names, query planning to match index columns, and key extraction to identify column IDs.

pub fn infer_stmt_ty(&self, stmt: &Statement, args: &[Type]) -> Type

pub fn infer_expr_ty(&self, expr: &Expr, args: &[Type]) -> Type

pub fn infer_expr_reference_ty(&self, expr_reference: &ExprReference) -> Type



impl<'a> ExprContext<'a>

pub fn target_as_model(&self) -> Option<&'a ModelRoot>

pub fn expr_ref_column(&self, column_id: impl Into<ColumnId>) -> ExprReference