Filter

Struct Filter 

pub struct Filter {
    pub expr: Option<Expr>,
}

Fields

expr: Option<Expr>

Implementations



impl Filter

pub const ALL: Filter

Default filters selects everything (i.e. no filter)

pub fn new(expr: impl Into<Expr>) -> Filter

pub fn and(lhs: impl Into<Filter>, rhs: impl Into<Filter>) -> Filter

pub fn as_expr(&self) -> &Expr

Returns the filter expression.

When no expression is set, returns true, which matches all rows.

pub fn into_expr(self) -> Expr

pub fn is_false(&self) -> bool

pub fn set(&mut self, expr: impl Into<Expr>)

pub fn add_filter(&mut self, filter: impl Into<Filter>)

pub fn take(&mut self) -> Filter

Takes the filter out, leaving an empty filter in its place.

Examples
let mut filter = Filter::default();
let taken = filter.take();
assert!(filter.expr.is_none());