Struct TypedInput
pub struct TypedInput<'a, I, T = Schema> { /* private fields */ }Expand description
An Input wrapper that validates resolved argument types against
expected types at resolution time.
TypedInput delegates resolution to an inner Input and then checks
that the resolved expression’s inferred type is a subtype of the
expected argument type from tys.
Implementations
impl<'a, I, T> TypedInput<'a, I, T>
impl<'a, I, T> TypedInput<'a, I, T>
pub fn new(
cx: ExprContext<'a, T>,
tys: &'a [Type],
input: I,
) -> TypedInput<'a, I, T>
pub fn new( cx: ExprContext<'a, T>, tys: &'a [Type], input: I, ) -> TypedInput<'a, I, T>
Creates a new TypedInput with the given expression context,
expected argument types, and inner input.