ValueStream

Struct ValueStream 

pub struct ValueStream { /* private fields */ }

Implementations



impl ValueStream

pub fn from_value(value: impl Into<Value>) -> ValueStream

pub fn from_stream<T>(stream: T) -> ValueStream
where T: Stream<Item = Result<Value, Error>> + Send + 'static,

pub fn from_vec(records: Vec<Value>) -> ValueStream

pub fn from_iter<T, I>(iter: I) -> ValueStream
where T: Into<Value>, I: Iterator<Item = Result<T, Error>> + Send + 'static,

pub async fn next(&mut self) -> Option<Result<Value, Error>>

Returns the next record in the stream

pub async fn peek(&mut self) -> Option<Result<&Value, Error>>

Peek at the next record in the stream

pub async fn tap(&mut self) -> Result<(), Error>

Force the stream to preload at least one record, if there are more records to stream.

pub fn min_len(&self) -> usize

The stream will contain at least this number of elements

pub async fn collect(self) -> Result<Vec<Value>, Error>

pub async fn dup(&mut self) -> Result<ValueStream, Error>

pub fn try_clone(&self) -> Option<ValueStream>

pub async fn buffer(&mut self) -> Result<(), Error>

pub fn is_buffered(&self) -> bool

Returns true if the ValueStream is fully buffered (no remaining stream)

pub fn buffered_to_vec(&self) -> Vec<Value>

Returns a clone of only the currently buffered values Does not consume any stream data or wait for additional values

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Value>

pub fn typed(self, ty: Type) -> ValueStream