Struct ValueStream
pub struct ValueStream { /* private fields */ }Implementations
impl ValueStream
impl ValueStream
pub fn from_value(value: impl Into<Value>) -> ValueStream
pub fn from_stream<T>(stream: T) -> ValueStream
pub fn from_vec(records: Vec<Value>) -> ValueStream
pub fn from_iter<T, I>(iter: I) -> ValueStream
pub async fn tap(&mut self) -> Result<(), Error>
pub async fn tap(&mut self) -> Result<(), Error>
Force the stream to preload at least one record, if there are more records to stream.
pub async fn collect(self) -> Result<Vec<Value>, Error>
pub async fn dup(&mut self) -> Result<ValueStream, Error>
pub fn try_clone(&self) -> Option<ValueStream>
pub async fn buffer(&mut self) -> Result<(), Error>
pub fn is_buffered(&self) -> bool
pub fn is_buffered(&self) -> bool
Returns true if the ValueStream is fully buffered (no remaining stream)
pub fn buffered_to_vec(&self) -> Vec<Value>
pub fn buffered_to_vec(&self) -> Vec<Value>
Returns a clone of only the currently buffered values Does not consume any stream data or wait for additional values
pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Value>
pub fn typed(self, ty: Type) -> ValueStream